<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "New Mexico";
    var qsoPartyUrl = "http://www.newmexicoqsoparty.org/";
    var overlayUrl = "http://www.no5w.com/OverlayNewMexicoRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Bernalillo", "ber");
  countySelection.options[1] = new Option("Catron", "cat");
  countySelection.options[2] = new Option("Chaves", "cha");
  countySelection.options[3] = new Option("Cibola", "cib");
  countySelection.options[4] = new Option("Colfax", "col");
  countySelection.options[5] = new Option("Curry", "cur");
  countySelection.options[6] = new Option("DeBaca", "deb");
  countySelection.options[7] = new Option("DonaAna", "don");
  countySelection.options[8] = new Option("Eddy", "edd");
  countySelection.options[9] = new Option("Grant", "gra");
  countySelection.options[10] = new Option("Guadalupe", "gua");
  countySelection.options[11] = new Option("Harding", "har");
  countySelection.options[12] = new Option("Hidalgo", "hid");
  countySelection.options[13] = new Option("Lea", "lea");
  countySelection.options[14] = new Option("Lincoln", "lin");
  countySelection.options[15] = new Option("LosAlamos", "los");
  countySelection.options[16] = new Option("Luna", "lun");
  countySelection.options[17] = new Option("McKinley", "mck");
  countySelection.options[18] = new Option("Mora", "mor");
  countySelection.options[19] = new Option("Otero", "ote");
  countySelection.options[20] = new Option("Quay", "qua");
  countySelection.options[21] = new Option("RioArriba", "rio");
  countySelection.options[22] = new Option("Roosevelt", "roo");
  countySelection.options[23] = new Option("Sandoval", "san");
  countySelection.options[24] = new Option("SanJuan", "sju");
  countySelection.options[25] = new Option("SanMiguel", "smi");
  countySelection.options[26] = new Option("SantaFe", "sfe");
  countySelection.options[27] = new Option("Sierra", "sie");
  countySelection.options[28] = new Option("Socorro", "soc");
  countySelection.options[29] = new Option("Taos", "tao");
  countySelection.options[30] = new Option("Torrance", "tor");
  countySelection.options[31] = new Option("Union", "uni");
  countySelection.options[32] = new Option("Valencia", "val");
  addMarker(35.04430000, -106.67300000, "Bernalillo", "ber");
  addMarker(33.89100000, -108.37900000, "Catron", "cat");
  addMarker(33.30380000, -104.43200000, "Chaves", "cha");
  addMarker(34.96300000, -108.05600000, "Cibola", "cib");
  addMarker(36.60690000, -104.69200000, "Colfax", "col");
  addMarker(34.62850000, -103.39100000, "Curry", "cur");
  addMarker(34.38750000, -104.41900000, "DeBaca", "deb");
  addMarker(32.41820000, -106.82000000, "DonaAna", "don");
  addMarker(32.48290000, -104.28700000, "Eddy", "edd");
  addMarker(32.53670000, -108.32800000, "Grant", "gra");
  addMarker(34.78180000, -104.71900000, "Guadalupe", "gua");
  addMarker(35.80420000, -103.90200000, "Harding", "har");
  addMarker(32.05510000, -108.62900000, "Hidalgo", "hid");
  addMarker(32.78540000, -103.43400000, "Lea", "lea");
  addMarker(33.73970000, -105.62900000, "Lincoln", "lin");
  addMarker(35.86390000, -106.29500000, "LosAlamos", "los");
  addMarker(32.19460000, -107.76300000, "Luna", "lun");
  addMarker(35.48090000, -108.17700000, "McKinley", "mck");
  addMarker(36.00830000, -105.02400000, "Mora", "mor");
  addMarker(32.69560000, -105.61300000, "Otero", "ote");
  addMarker(35.17230000, -103.58500000, "Quay", "qua");
  addMarker(36.46540000, -106.57900000, "RioArriba", "rio");
  addMarker(34.08760000, -103.49700000, "Roosevelt", "roo");
  addMarker(35.71740000, -106.93600000, "Sandoval", "san");
  addMarker(36.50020000, -108.23400000, "SanJuan", "sju");
  addMarker(35.45630000, -104.68000000, "SanMiguel", "smi");
  addMarker(35.52120000, -105.98200000, "SantaFe", "sfe");
  addMarker(33.04260000, -107.17100000, "Sierra", "sie");
  addMarker(34.02790000, -106.82500000, "Socorro", "soc");
  addMarker(36.50450000, -105.62900000, "Taos", "tao");
  addMarker(34.65090000, -105.88100000, "Torrance", "tor");
  addMarker(36.36980000, -103.50600000, "Union", "uni");
  addMarker(34.69750000, -106.80800000, "Valencia", "val");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

